{% extends 'base.html' %}

{% block title %}Chef role: {{ role.name }}{% endblock %}
{% block header %}{{ role.name }}{% endblock %}

{% block breadcrumbs %}
  {{ super() }}
  <li><a href="{{ url_for('ui.roles') }}">Chef roles</a></li>
  <li class="active">{{ role.name }}</li>
{% endblock %}

{% block content %}
<ul class="attempt-columns">
{% for node in nodes %}
  <li>
    <a href="{{ url_for('.node', name=node) }}">
      <code>{{ node }}</code>
    </a>
  </li>
{% endfor %}
</ul>
{% endblock %}
