{% extends 'base.html' %}

{% block title %}Chef nodes{% endblock %}

{% block breadcrumbs %}
  {{ super() }}
  <li class="active">{{ self.title() }}</li>
{% endblock %}

{% block content %}
<ul class="attempt-columns">
{% for node_name in nodes %}
  <li>
    <a href="{{ url_for('.node', name=node_name) }}">
      <code>{{ node_name }}</code>
    </a>
  </li>
{% endfor %}
</ul>
{% endblock %}
