{% extends 'base.html' %}

{% block title %}Chef roles{% endblock %}

{% block breadcrumbs %}
  {{ super() }}
  <li class="active">Roles</li>
{% endblock %}

{% block content %}
<ul class="attempt-columns">
{% for role_name in roles %}
  <li>
    <a href="{{ url_for('.role', name=role_name) }}">
      <code>{{ role_name }}</code>
    </a>
  </li>
{% endfor %}
</ul>
{% endblock %}
