#footer {
	margin-top: 1em;
	margin-bottom: 1em;
}

/* Color code blocks in links differently */
a code {
	color: #428BCA;
	background-color: #F4F8FA;
}

a:hover code {
	color: #2A6496;
}

/* Small devices (tablets, 768px and up) */
@media (min-width: 768px) {

}

/* Medium devices (desktops, 992px and up) */
@media (min-width: 992px) {
	.attempt-columns {
		-webkit-column-count: 2;
		-moz-column-count: 2;
		column-count: 2;
	}
}

/* Large devices (large desktops, 1200px and up) */
@media (min-width: 1200px) {

}
